# Model that infers a person's tension from his or her face photo.

## What is this model?

You can create chatAPP, example, that can be friends with you!
Example movie URL ：
This model speculate your feeling level from your face images.When you happened what is happy, the chat APP that used this model chats with you 同じだけのテンションで

### What does this model do?

### BackGround
